Fae is a small 2D graphics rendering crate, with the main intended use-case being 2D games. Its main goals are simplicity, performance, and compatiblity.
Modules
- The errors that fae can return.
- OpenGL functions and constants.
- Module for reading the profiling data that
faecollects. If theprofilerfeature is disabled, all the functions are no-ops, and there will be no profiling overhead. Probably not very useful outside of this crate’s development.
Structs
- Describes how a spritesheet should be blended with the background.
- The overarching state of the crate. Intended to live outside of the main game loop.
- Holds a font for rendering. See also:
Font::draw. - Draw stuff on the screen with this.
- Contains the raw pixel color data of an image.
- Represents a rectangle.
- Contains the code for a vertex shader and a fragment shader.
- Contains the shader code for a spritesheet.
- Sprite builder struct. Call
finishto draw the sprite. - Holds a texture for rendering.
- A builder for
Spritesheet. - Text builder struct. Call
finishto draw the text.
Enums
- Defines the alignment of text.
- A generic error type that wraps fae’s other error types in the
fae::errorsmodule. - Represents the two different variants of OpenGL.
- Represents the parsed version of the OpenGL version string.
- Describes how textures are wrapped.