Module profiler

Module profiler 

Module for reading the profiling data that fae collects. If the profiler feature is disabled, all the functions are no-ops, and there will be no profiling overhead. Probably not very useful outside of this crate’s development.

If using this, remember to call profiler::refresh() at the start of each frame!

Structs

ProfilingData
The data collected by fae internals. Returned by profiler::read.

Functions

read
Returns a copy of the last frame’s profiling data. If the profiler feature is disabled, it will always be zeroed and initialized on the spot.
refresh
Resets frame-specific counters.