ProfilingData

Struct ProfilingData 

pub struct ProfilingData {
    pub glyph_cache_misses: u32,
    pub glyph_cache_hits: u32,
    pub glyphs_drawn: u32,
    pub quads_drawn: u32,
    pub glyphs_rasterized: u32,
}
The data collected by fae internals. Returned by profiler::read.

Fields

glyph_cache_misses: u32

The amount of glyphs that had to be rasterized during this frame (ie. they weren’t in the glyph cache, and drawing the glyph was slow, as it had to be rasterized).

glyph_cache_hits: u32

The amount of glyphs that didn’t have to rasterized during this frame (ie. they were in the glyph cache, and drawing the glyph was very fast).

glyphs_drawn: u32

The amount of glyphs that were rendered during this frame.

quads_drawn: u32

The amount of quads that were rendered during this frame (includes the glyphs, each one is a quad).

glyphs_rasterized: u32

The amount of times a glyph had to be rasterized in the application so far.